<?php

namespace Controller;

use React\Stream\Util;
use Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\File;
use Zeedhi\Framework\Routing\Exception;

class Repository  extends Simple {

    protected $repositoryService;

    public function __construct(\Service\Repository $repositoryService){
        $this->repositoryService = $repositoryService;
    }

    public function findAllRepositories(Request\Filter $request, Response $response){
    	$filter = $request->getFilterCriteria()->getConditions();
    	$project = empty($filter[0]) ? null : $filter[0]['value'];
    	$filter  = Utilities::getFilterTableColumn($filter, 'URL');
        $repositories = $this->repositoryService->getAllRepositories($project, $filter);
        $response->addDataSet(new DataSet('findAllRepositories', $repositories));
    }

    public function findProjectRepositories(Request\Filter $request, Response $response){
        $conditions = $request->getFilterCriteria()->getConditions();
        $project = Utilities::getValueInFilterDataSourceByName($conditions, 'PROJECT', true);
        $project = $project ? $project: 0;
        Utilities::getValueInFilterDataSourceByName($conditions, 'ID', true);
        $filter = Utilities::createQueryFiltered($conditions, 'R');
        $repositories = $this->repositoryService->findProjectRepositories($project, $filter);
        $response->addDataSet(new DataSet('projectRepositories', $repositories));

    }

    public function findRepositoriesWithFilter(Request\Filter $request, Response $response){//method from projectRepository
        $conditions = $request->getFilterCriteria()->getConditions();
        $repositories = $this->repositoryService->findRepositoriesWithFilter($conditions);
        $response->addDataSet(new DataSet('projectRepositories', $repositories));

    }

    public function findRepositories(Request\Filter $request, Response $response){
        $repositories = $this->repositoryService->findRepositories();
        $response->addDataSet(new DataSet('projectRepositories', $repositories));
    }

    public function findResourceProjectRepositories(Request\Filter $request, Response $response){
        $conditions = $request->getFilterCriteria()->getConditions();
        $resource = $conditions[0]['value'];
        $project = $conditions[1]['value'] === 'null' ? null : $conditions[1]['value'];
        $repositories = $this->repositoryService->findResourceProjectRepositories($resource, $project);
        $response->addDataSet(new DataSet('resourceProjectRepositories', $repositories));

    }

    public function getRepositoriesByTaskId(Request\Filter $request, Response $response){
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $taskId = Utilities::getValueInFilterDataSourceByName($conditions, 'TASK_ID');
            $repositories = $this->repositoryService->getRepositoriesByTaskId($taskId);
            $response->addDataSet(new DataSet('getRepositoriesByTaskId', $repositories));
        }catch(\Exception $ex){
            $response->addDataSet(new DataSet('getRepositoriesByTaskId', []));
        }

    }


    public function deleteProjectRepositories($request, Response $response){
        $count = 0;
        if($request instanceof Request\DataSet){
            $dataSet = $request->getDataSet()->getRows();

            foreach ($dataSet as $param) {
                try{
                    $repository = $param['ID'];
                    $project = empty($param['PROJECT']) ? null : $param['PROJECT'];
                    $this->repositoryService->deleteProjectRepositories($repository, $project);
                }catch(\Exception $ex){
                    $response->addMessage(new Response\Message(\Util\Messages::ERR_NOT_SUCCESSFUL_DELETED_EXPLANATION . $ex->getMessage()));
                    $count--;
                }
                $count++;
            }
            $response->addMessage(new Response\Message("$count repositórios deletados."));
        }else{
            $dataSet = $request->getRow();
            try{
                $repository = $dataSet['ID'];
                $project = empty($dataSet['PROJECT']) ? null : $dataSet['PROJECT'];
                $this->repositoryService->deleteProjectRepositories($repository, $project);
                $response->addNotification(new Response\Notification("Repositório deletado."));
            }catch(\Exception $ex){
                $response->addMessage(new Response\Message(\Util\Messages::ERR_NOT_SUCCESSFUL_DELETED_EXPLANATION . $ex->getMessage()));
            }
        }

    }

}