<?php
namespace Zeedhi\DevOps\Model\Servermanager\Repositories;

use Zeedhi\DevOps\Model\Configurationmanager\Entities\Product as ProductEntity;
use Zeedhi\DevOps\Model\Servermanager\Entities\ProductServer as ProductServerEntity;

class ProductServer extends \Doctrine\ORM\EntityRepository {
    
    public function findProductWithServerBasePath($serverId, $filetrs)
    {
        $query = <<<SQL
            SELECT *
              FROM (SELECT PRO.ID AS PRODUCT_ID, PRO.NAME AS PRODUCT_NAME, PRS.PATH AS SERVER_BASE_PATH, PRS.ID AS PRODUCT_SERVER_ID,
                           DECODE(PKG.PATH_TO_DEPLOY, NULL,
                                  (SELECT PCK.PATH_TO_DEPLOY
                                     FROM PACKAGE PCK
                                    WHERE PCK.PRODUCT_ID = PRO.ID
                                      AND ROWNUM = 1),
                                  PKG.PATH_TO_DEPLOY) AS PATH_TO_DEPLOY
                      FROM PRODUCT_SERVER PRS
                INNER JOIN PRODUCT PRO ON PRO.ID = PRS.PRODUCT_ID
                 LEFT JOIN PACKAGE PKG ON PKG.ID = PRS.PACKAGE_ID
                     WHERE SERVER_ID     = :SERVER_ID
                       AND PRS.IS_ACTIVE = :IS_ACTIVE_PRODUCT_SERVER
                       AND PRO.IS_ACTIVE = :IS_ACTIVE_PRODUCT
                       AND USETYPE       = :USE_TYPE)
          $filetrs
          ORDER BY PRODUCT_ID
SQL;
        
        $params = array(
            'SERVER_ID'                 => $serverId,
            'IS_ACTIVE_PRODUCT_SERVER'  => ProductServerEntity::IS_ACTIVE_POSITIVE,
            'IS_ACTIVE_PRODUCT'         => ProductEntity::IS_ACTIVE_POSITIVE,
            'USE_TYPE'                  => ProductServerEntity::TYPE_PRODUCTION
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
    
}